Installation — PyHarmX 0.1.0 documentation

# Installation

Install PyHarmX using the following command:

    pip install pyharmx

PyHarmX has minimal dependencies, requiring only PyTorch and NumPy.

If you’re interested in contributing or want to use PyHarmX in developer/editable mode with test dependencies, install it as follows:

    pip install -e pyharmx[test]

To run the tests, simply execute:

    pytest <path-to-pyharmx>

# Explore

Check out the examples provided in the repository to see PyHarmX in action.

# License

PyHarmX is distributed under the MIT License. Feel free to use, modify, and contribute to this project within the terms of the license.